==> ws_event-1.0.15.tar.gz: ws_event/src/Plugin/Block/EventInfoBlock.php <==
<?php

namespace Drupal\ws_event\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Link;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Url;
use Drupal\datetime\Plugin\Field\FieldType\DateTimeItemInterface;
use Drupal\node\NodeInterface;
use Drupal\ws_event\EventDataHelper;
use LinkedIn\Exception;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an Event Info block.
 *
 * @Block(
 *   id = "lb_event_info",
 *   admin_label = @Translation("Event Info Block"),
 *   category = @Translation("Event blocks")
 * )
 */
class EventInfoBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\CurrentRouteMatch
   */
  protected $currentRouteMatch;

  /**
   * Cuurent node.
   *
   * @var \Drupal\node\Entity\Node
   */
  protected $node;


  /**
   * Logger channel for the Y-LB.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Event data helper service.
   *
   * @var \Drupal\ws_event\EventDataHelper
   */
  protected $eventDataHelper;

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new EventInfoBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration, i.e. an array with configuration values keyed
   *   by configuration option name. The special key 'context' may be used to
   *   initialize the defined contexts by setting it to an array of context
   *   values keyed by context names.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Routing\CurrentRouteMatch $currentRouteMatch
   *   The current route match service.
   * * @param \Drupal\ws_event\EventDataHelper $eventDataHelper
   *   Event data helper service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CurrentRouteMatch $currentRouteMatch, EventDataHelper $eventDataHelper, LoggerChannelFactoryInterface $loggerFactory, EntityTypeManagerInterface $entityTypeManager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentRouteMatch = $currentRouteMatch;
    $this->eventDataHelper = $eventDataHelper;
    $this->node = $currentRouteMatch->getParameter('node');
    $this->logger = $loggerFactory->get('y_lb');
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match'),
      $container->get('ws_event.event_data_helper'),
      $container->get('logger.factory'),
      $container->get('entity_type.manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    if (!$this->node || !$this->node->hasField('field_event_location')) {
      return [];
    }

    $location = $this->node->get('field_event_location')->entity;
    $date = $this->eventDataHelper->getFormattedDateRange($this->node);
    $time = $this->eventDataHelper->getFormattedDateRange($this->node, EventDataHelper::DATE_RANGE_TIME_FORMAT);
    if ($this->node->hasField('field_location_address') &&
      ($fieldAddress = $this->node->get('field_location_address')) &&
      !$fieldAddress->isEmpty()) {
      $address = $this->getAddress($location, $fieldAddress->first());
      $directions = $this->getDirections($this->node);
      $locationLink = '';
    } else {
      if (!$location) {
        return [];
      }
      $address = $this->getAddress($location);
      $directions = $this->getDirections($location);
      $locationLink = $this->getLocationLink($location);
    }

    $build = [
      '#date' => $date,
      '#time' => $time,
      '#location_link' => $locationLink,
      '#location_address' => $address,
      '#location_directions' => $directions,
    ];

    if ($atcData = $this->getAtcData()) {
      $build['#atc'] = $atcData;
    }
    return $build;
  }


  /**
   * Add location and date information to event
   *
   * @return array
   */
  protected function getAtcData() {
    $datesField = $this->node->get('field_event_dates')->getValue();
    if (empty($datesField[0])) {
      return [];
    }
    $timezone = date_default_timezone_get();
    $startDt = DrupalDateTime::createFromFormat(DateTimeItemInterface::DATETIME_STORAGE_FORMAT, $datesField[0]['value'], DateTimeItemInterface::STORAGE_TIMEZONE);
    $startDt->setTimezone(timezone_open($timezone));
    $endDt = DrupalDateTime::createFromFormat(DateTimeItemInterface::DATETIME_STORAGE_FORMAT, $datesField[0]['end_value'], DateTimeItemInterface::STORAGE_TIMEZONE);
    $endDt->setTimezone(timezone_open($timezone));

    $description = '';
    $descriptionValue = $this->node->get('body')->getValue();
    if (!empty($descriptionValue) && ($description = $descriptionValue[0]['value'])) {
      $description = strip_tags($description);
      $description = strlen($description) > 300 ? substr($description, 0, 300) . ' ...' : $description;
    }
    $datesAtc = [
      'atc_date_start' => $startDt->format('Y-m-d H:i:s', ['timezone' => $timezone]),
      'atc_date_end' => $endDt->format('Y-m-d H:i:s', ['timezone' => $timezone]),
      'atc_timezone' => $timezone,
      'atc_title' => $this->node->getTitle(),
      'atc_description' => $description,
    ];

    // Get locations.
    $locationField = $this->node->get('field_event_location')->getValue();
    $locationField = reset($locationField);
    $location = $this->entityTypeManager->getStorage('node')->load($locationField['target_id']);
    if ($location instanceof NodeInterface) {
      $locTitle = $location->getTitle();
      $datesAtc['atc_location'] = $locTitle;
      $datesAtc['atc_organizer'] = $locTitle;
    }

    return $datesAtc;
  }

  /**
   * Returns formatted Location address.
   *
   * @param \Drupal\node\NodeInterface $location
   *
   * @return \Drupal\Component\Render\MarkupInterface|string
   */
  protected function getAddress($location, $address = NULL) {
    if(!$address) {
      $address = $location->get('field_location_address')->first();
    }
    if ($address) {
      $address_array = $address->toArray();
      $location_address = "{$address_array['address_line1']}<br />{$address_array['locality']}<br /> {$address_array['administrative_area']} {$address_array['postal_code']}";
      return Markup::create($location_address);
    }
    return '';
  }

  /**
   * Returns render array for the Location Directions Link or empty string.
   *
   * @param \Drupal\node\NodeInterface $node
   *
   * @return array|mixed|string
   */
  protected function getDirections($node) {
    if (
      in_array($node->getType(), ['branch', 'camp', 'facility', 'location', 'lb_event']) &&
      $node->hasField('field_location_directions')
    ) {
      $directions_title = t("Directions");
      if (!$node->field_location_directions->isEmpty()) {
        $directions_field_url = $node->field_location_directions->get(0);
        if ($directions_field_url && $directions_field_url->getUrl()->toString() !== "") {
          $title = $directions_field_url->get('title')->getValue() ?? $directions_title;
          return Link::fromTextAndUrl($title, $directions_field_url->getUrl());
        }
        if ($directions_field_url->title) {
          $directions_title = $directions_field_url->title;
        }
      }

      $address = $node->field_location_address->get(0);
      if ($address) {
        $address_array = $address->toArray();
        $location_address = "{$address_array['address_line1']} {$address_array['locality']}, {$address_array['administrative_area']} {$address_array['postal_code']}";
        $directions_url = Url::fromUri('https://www.google.com/maps/dir/', [
          'query' => [
            'api' => 1,
            'destination' => $location_address,
          ],
        ]);

        $link = Link::fromTextAndUrl($directions_title, $directions_url);
        $link = $link->toRenderable();
        $link['#attributes'] = ['target' => ['_blank']];
        return $link;
      }
    }
    return '';
  }

  /**
   * Returns Location link.
   *
   * @param \Drupal\node\NodeInterface $location
   *
   * @return \Drupal\Core\Link
   */
  protected function getLocationLink($location) {
    $url = $location->toUrl();
    return Link::fromTextAndUrl($location->label(), $url);
  }

  /**
   * Helper method to build Date/Time strings from node data.
   *
   * @return array
   */
  protected function getDateTime(){
    $result = [
      'date' => '',
      'time' => ''
    ];

    $formatDate = 'F j, Y';
    $formatTime = 'g:i a';

    try {
      $startDate = $this->node->field_event_dates->value;
      $endDate = $this->node->field_event_dates->end_value;

      $start = new \DateTimeImmutable($startDate);
      $end = new \DateTimeImmutable($endDate);

      $result['date'] = $start->format($formatDate);
      // Start and end time differs
      if ($end->diff($start)->h > 0) {
        $result['time'] = $start->format($formatTime) . ' - ' . $end->format($formatTime);
      }
      else {
        $result['time'] = $end->format($formatTime);
      }
    }
    catch (Exception $e) {
      $this->logger->debug($e->getMessage());
    }

    return $result;
  }

}

==> ws_event-1.1.7.tar.gz: ws_event/src/Plugin/Block/EventInfoBlock.php <==
<?php

namespace Drupal\ws_event\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Link;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Url;
use Drupal\datetime\Plugin\Field\FieldType\DateTimeItemInterface;
use Drupal\node\NodeInterface;
use Drupal\ws_event\EventDataHelper;
use LinkedIn\Exception;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an Event Info block.
 *
 * @Block(
 *   id = "lb_event_info",
 *   admin_label = @Translation("Event Info Block"),
 *   category = @Translation("Event blocks")
 * )
 */
class EventInfoBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\CurrentRouteMatch
   */
  protected $currentRouteMatch;

  /**
   * Cuurent node.
   *
   * @var \Drupal\node\Entity\Node
   */
  protected $node;


  /**
   * Logger channel for the Y-LB.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Event data helper service.
   *
   * @var \Drupal\ws_event\EventDataHelper
   */
  protected $eventDataHelper;

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new EventInfoBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration, i.e. an array with configuration values keyed
   *   by configuration option name. The special key 'context' may be used to
   *   initialize the defined contexts by setting it to an array of context
   *   values keyed by context names.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Routing\CurrentRouteMatch $currentRouteMatch
   *   The current route match service.
   *   * @param \Drupal\ws_event\EventDataHelper $eventDataHelper
   *   Event data helper service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CurrentRouteMatch $currentRouteMatch, EventDataHelper $eventDataHelper, LoggerChannelFactoryInterface $loggerFactory, EntityTypeManagerInterface $entityTypeManager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentRouteMatch = $currentRouteMatch;
    $this->eventDataHelper = $eventDataHelper;
    $this->node = $currentRouteMatch->getParameter('node');
    $this->logger = $loggerFactory->get('y_lb');
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match'),
      $container->get('ws_event.event_data_helper'),
      $container->get('logger.factory'),
      $container->get('entity_type.manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    if (!$this->node || !$this->node->hasField('field_event_location')) {
      return [];
    }

    $location = $this->node->get('field_event_location')->entity;
    $date = $this->eventDataHelper->getFormattedDateRange($this->node);
    $time = $this->eventDataHelper->getFormattedDateRange($this->node, EventDataHelper::DATE_RANGE_TIME_FORMAT);
    if ($this->node->hasField('field_location_address') &&
      ($fieldAddress = $this->node->get('field_location_address')) &&
      !$fieldAddress->isEmpty()) {
      $address = $this->getAddress($location, $fieldAddress->first());
      $directions = $this->getDirections($this->node);
      $locationLink = '';
    }
    else {
      if (!$location) {
        return [];
      }
      $address = $this->getAddress($location);
      $directions = $this->getDirections($location);
      $locationLink = $this->getLocationLink($location);
    }

    $build = [
      '#date' => $date,
      '#time' => $time,
      '#location_link' => $locationLink,
      '#location_address' => $address,
      '#location_directions' => $directions,
    ];

    if ($atcData = $this->getAtcData()) {
      $build['#atc'] = $atcData;
    }
    return $build;
  }

  /**
   * Add location and date information to event.
   *
   * @return array
   */
  protected function getAtcData() {
    $datesField = $this->node->get('field_event_dates')->getValue();
    if (empty($datesField[0])) {
      return [];
    }
    $timezone = date_default_timezone_get();
    $startDt = DrupalDateTime::createFromFormat(DateTimeItemInterface::DATETIME_STORAGE_FORMAT, $datesField[0]['value'], DateTimeItemInterface::STORAGE_TIMEZONE);
    $startDt->setTimezone(timezone_open($timezone));
    $endDt = DrupalDateTime::createFromFormat(DateTimeItemInterface::DATETIME_STORAGE_FORMAT, $datesField[0]['end_value'], DateTimeItemInterface::STORAGE_TIMEZONE);
    $endDt->setTimezone(timezone_open($timezone));

    $description = '';
    $descriptionValue = $this->node->get('body')->getValue();
    if (!empty($descriptionValue) && ($description = $descriptionValue[0]['value'])) {
      $description = strip_tags($description);
      $description = strlen($description) > 300 ? substr($description, 0, 300) . ' ...' : $description;
    }
    $datesAtc = [
      'atc_date_start' => $startDt->format('Y-m-d H:i:s', ['timezone' => $timezone]),
      'atc_date_end' => $endDt->format('Y-m-d H:i:s', ['timezone' => $timezone]),
      'atc_timezone' => $timezone,
      'atc_title' => $this->node->getTitle(),
      'atc_description' => $description,
    ];

    // Get locations.
    $locationField = $this->node->get('field_event_location')->getValue();
    $locationField = reset($locationField);
    $location = $this->entityTypeManager->getStorage('node')->load($locationField['target_id']);
    if ($location instanceof NodeInterface) {
      $locTitle = $location->getTitle();
      $datesAtc['atc_location'] = $locTitle;
      $datesAtc['atc_organizer'] = $locTitle;
    }

    return $datesAtc;
  }

  /**
   * Returns formatted Location address.
   *
   * @param \Drupal\node\NodeInterface $location
   *
   * @return \Drupal\Component\Render\MarkupInterface|string
   */
  protected function getAddress($location, $address = NULL) {
    if (!$address) {
      $address = $location->get('field_location_address')->first();
    }
    if ($address) {
      $address_array = $address->toArray();
      $location_address = "{$address_array['address_line1']}<br />{$address_array['locality']}<br /> {$address_array['administrative_area']} {$address_array['postal_code']}";
      return Markup::create($location_address);
    }
    return '';
  }

  /**
   * Returns render array for the Location Directions Link or empty string.
   *
   * @param \Drupal\node\NodeInterface $node
   *
   * @return array|mixed|string
   */
  protected function getDirections($node) {
    if (
      in_array($node->getType(), ['branch', 'camp', 'facility', 'location', 'lb_event']) &&
      $node->hasField('field_location_directions')
    ) {
      $directions_title = t("Directions");
      if (!$node->field_location_directions->isEmpty()) {
        $directions_field_url = $node->field_location_directions->get(0);
        if ($directions_field_url && $directions_field_url->getUrl()->toString() !== "") {
          $title = $directions_field_url->get('title')->getValue() ?? $directions_title;
          return Link::fromTextAndUrl($title, $directions_field_url->getUrl());
        }
        if ($directions_field_url->title) {
          $directions_title = $directions_field_url->title;
        }
      }

      $address = $node->field_location_address->get(0);
      if ($address) {
        $address_array = $address->toArray();
        $location_address = "{$address_array['address_line1']} {$address_array['locality']}, {$address_array['administrative_area']} {$address_array['postal_code']}";
        $directions_url = Url::fromUri('https://www.google.com/maps/dir/', [
          'query' => [
            'api' => 1,
            'destination' => $location_address,
          ],
        ]);

        $link = Link::fromTextAndUrl($directions_title, $directions_url);
        $link = $link->toRenderable();
        $link['#attributes'] = ['target' => ['_blank']];
        return $link;
      }
    }
    return '';
  }

  /**
   * Returns Location link.
   *
   * @param \Drupal\node\NodeInterface $location
   *
   * @return \Drupal\Core\Link
   */
  protected function getLocationLink($location) {
    $url = $location->toUrl();
    return Link::fromTextAndUrl($location->label(), $url);
  }

  /**
   * Helper method to build Date/Time strings from node data.
   *
   * @return array
   */
  protected function getDateTime() {
    $result = [
      'date' => '',
      'time' => '',
    ];

    $formatDate = 'F j, Y';
    $formatTime = 'g:i a';

    try {
      $startDate = $this->node->field_event_dates->value;
      $endDate = $this->node->field_event_dates->end_value;

      $start = new \DateTimeImmutable($startDate);
      $end = new \DateTimeImmutable($endDate);

      $result['date'] = $start->format($formatDate);
      // Start and end time differs.
      if ($end->diff($start)->h > 0) {
        $result['time'] = $start->format($formatTime) . ' - ' . $end->format($formatTime);
      }
      else {
        $result['time'] = $end->format($formatTime);
      }
    }
    catch (Exception $e) {
      $this->logger->debug($e->getMessage());
    }

    return $result;
  }

}
